@@ -622,6 +622,11 @@ class TestAcl(unittest.TestCase):
 
         self.assertTrue(data.get('totalCount') == 1)
 
+        item = data['list'][0]
+        self.assertTrue(item['code'] == 'books:123')
+        self.assertTrue(item['type'] == 'DATA')
+        self.assertTrue(item['actions'][0] == 'books:edit')
+
     def test_get_authorized_targets(self):
         data = management.acl.get_authorized_targets(namespace="mvcbbdutsn", resource_type="DATA", resource="test",target_type="GROUP")
         print (data)
