@@ -1267,6 +1267,16 @@ class TestUsers(unittest.TestCase):
         success = management.users.kick(['5a597f35085a2000144a10ed'])
         self.assertTrue(success)
 
+    def test_has_role(self):
+        code = get_random_string(10)
+        management.roles.create(
+            code=code
+        )
+        user = create_user()
+        management.users.add_roles(user.get('id'), [code])
+        has_role = management.users.has_role(user.get('id'), code)
+        self.assertTrue(has_role)
+
     def test_list_user_actions(self):
         res = management.users.list_user_actions()
         print(res)
@@ -1294,4 +1304,4 @@ class TestUsers(unittest.TestCase):
 
     def test_check_login_status(self):
         res = management.users.check_login_status("613872b19c90be7d4da44466")
-        self.assertEquals(res['message'],'用户不存在')
\ No newline at end of file
+        self.assertEquals(res['message'],'用户不存在')
